==> mailosaur-java-8.1.0-sources.jar: com/mailosaur/models/MessageForwardOptions.java <==
package com.mailosaur.models;

import com.google.api.client.util.Key;

/**
 * Options to use when forwarding a message.
 */
public class MessageForwardOptions {
    /**
     * The email address to which the email will be sent. Must be a verified email address.
     */
	@Key
    private String to;

    /**
     * Any plain text to include when forwarding the message. Note that only text or html can be supplied, not both.
     */
	@Key
    private String text;

    /**
     * Any HTML content to include when forwarding the message. Note that only text or html can be supplied, not both.
     */
	@Key
    private String html;

    /**
     * Sets the email address to which the email will be sent. Must be a verified email address.
     *
     * @param to The email address.
     * @return the MessageForwardOptions object itself.
     */
    public MessageForwardOptions withTo(String to) {
        this.to = to;
        return this;
    }

    /**
     * Sets any plain text to include when forwarding the message. Note that only text or html can be supplied, not both.
     *
     * @param text Plain text content to include when forwarding the message.
     * @return the MessageForwardOptions object itself.
     */
    public MessageForwardOptions withText(String text) {
        this.text = text;
        return this;
    }

    /**
     * Sets any HTML content to include when forwarding the message. Note that only text or html can be supplied, not both.
     *
     * @param html HTML content to include when forwarding the message.
     * @return the MessageForwardOptions object itself.
     */
    public MessageForwardOptions withHtml(String html) {
        this.html = html;
        return this;
    }
}

==> mailosaur-java-8.3.0-sources.jar: com/mailosaur/models/MessageForwardOptions.java <==
package com.mailosaur.models;

import com.google.api.client.util.Key;

/**
 * Options to use when forwarding a message.
 */
public class MessageForwardOptions {
    /**
     * The email address to which the email will be sent. Must be a verified email address.
     */
	@Key
    private String to;

    /**
     * The email address to which the email will be CC'd. Must be a verified email address.
     */
	@Key
    private String cc;

    /**
     * Any plain text to include when forwarding the message. Note that only text or html can be supplied, not both.
     */
	@Key
    private String text;

    /**
     * Any HTML content to include when forwarding the message. Note that only text or html can be supplied, not both.
     */
	@Key
    private String html;

    /**
     * Sets the email address to which the email will be sent. Must be a verified email address.
     *
     * @param to The email address.
     * @return the MessageForwardOptions object itself.
     */
    public MessageForwardOptions withTo(String to) {
        this.to = to;
        return this;
    }

    /**
     * Sets the email address to which the email will be CC'd. Must be a verified email address.
     *
     * @param cc The email address.
     * @return the MessageCreateOptions object itself.
     */
    public MessageForwardOptions withCc(String cc) {
        this.cc = cc;
        return this;
    }

    /**
     * Sets any plain text to include when forwarding the message. Note that only text or html can be supplied, not both.
     *
     * @param text Plain text content to include when forwarding the message.
     * @return the MessageForwardOptions object itself.
     */
    public MessageForwardOptions withText(String text) {
        this.text = text;
        return this;
    }

    /**
     * Sets any HTML content to include when forwarding the message. Note that only text or html can be supplied, not both.
     *
     * @param html HTML content to include when forwarding the message.
     * @return the MessageForwardOptions object itself.
     */
    public MessageForwardOptions withHtml(String html) {
        this.html = html;
        return this;
    }
}
